
/*------------------------------------------------------------------------
    File        : aa-2301-after-02-srv-mail-parameters.p
    Purpose     :

    Syntax      :

    Description : EMAIL aa-edi-srv-pars hernoemd, hier omzetten

    Author(s)   :
    Created     : 21-11-2022 rdb
    Notes       :
                  - zet nooit een include in je conversie programma's, deze staan niet in de uitleverset
                    (met uitzondering van system/conversion.conversion_progress.i)
                  - als de database triggers niet persee af hoeven te gaan , disable ze dan

                  - gebruik de procedure 'DisplayProgress' om info/voortgang en tellers te tonen
                  - gebruik de FIELDS optie als je maar weinig velden hoeft te updaten.

                  - OF gebruik het TRANSACTION keyword als je bij de FOR EACH een EXCLUSIVE-LOCK opgeeft
                    zie onderstaand voorbeeld A

                  - OF gebruik een buffer voor de tabel als je de FOR EACH met NO-LOCK leest
                    zie onderstaand voorbeeld B

  ----------------------------------------------------------------------*/

/* ***************************  Definitions  ************************** */

/* Deze standaard include toevoegen aan conversie programmatuur,
   o.a de DisplayProgress procedure en input paramatere naar de
   aanroepende procedure worden hier in gedefineerd.
   Hierdoor wordt de aansluiting naar de update procedure gemaakt.

   Opmerking: Deze include wordt opgenomen in de System/comversion
              directory welke als ongecompileerd bestand.
              Het is de enige include die opgenomen mag worden in
              de conversie programmatuur.
*/
/* standalone preprocessor even op iets anders zetten als je deze handmatig wil draaien */
&SCOPED-DEFINE standalone NO

&IF {&standalone} = NO &THEN
{System/conversion/conversion_progress.i}
&ENDIF

/* ********************  Preprocessor Definitions  ******************** */


/* ***************************  Main Block  *************************** */
DEF VAR cProgram                      AS CHAR NO-UNDO.
DEF VAR cAction                       AS CHAR NO-UNDO.
DEF VAR cTable                        AS CHAR NO-UNDO.
DEF VAR cSeqcode                      AS CHAR NO-UNDO.
DEF VAR iTotal                        AS INT  NO-UNDO.
DEF VAR iDone                         AS INT  NO-UNDO.
DEF VAR iModulo                       AS INT  NO-UNDO.

DISABLE TRIGGERS FOR LOAD OF aa-edi-srv-par.

cProgram =  THIS-PROCEDURE:FILE-NAME.
cAction  = "Convert email parameters".
cTable = "aa-edi-srv-par".
iModulo =  1000.  /* om de 1000 records info tonen */


RUN DisplayProgress (cProgram, cAction, cTable, iTotal, iDone).

/* even tellen  */
iTotal = 0.
iDone = 0.


DEFINE BUFFER b1-aa-edi-srv-par FOR aa-edi-srv-par.
DEFINE BUFFER b2-aa-edi-srv-par FOR aa-edi-srv-par.
DEFINE BUFFER b3-aa-edi-srv-par FOR aa-edi-srv-par.

  /* is er een mail profile ingesteld? (dit was voorheen hardcoded in aa-edi-srv-email.p */
  FIND b1-aa-edi-srv-par WHERE 
       b1-aa-edi-srv-par.service_code = 'EMAIL'
  AND  b1-aa-edi-srv-par.par_name = 'mail_profile'
       EXCLUSIVE-LOCK NO-ERROR.
  IF AVAILABLE b1-aa-edi-srv-par
  THEN DO:
    
    /* version selectie zetten */
    FIND b2-aa-edi-srv-par WHERE 
           b2-aa-edi-srv-par.service_code = 'EMAIL'
      AND  b2-aa-edi-srv-par.par_name = 'smtpversion'
      EXCLUSIVE-LOCK NO-ERROR.
    IF NOT AVAILABLE b2-aa-edi-srv-par
    THEN DO:
      CREATE b2-aa-edi-srv-par.
      ASSIGN 
      b2-aa-edi-srv-par.service_code = 'EMAIL'
      b2-aa-edi-srv-par.par_name = 'smtpversion'
      .
    END.
    ASSIGN 
      b2-aa-edi-srv-par.par_value = 'send-mail-profile'
      .
    
    /* profile instellen */
    FIND b3-aa-edi-srv-par WHERE 
           b3-aa-edi-srv-par.service_code = 'EMAIL'
      AND  b3-aa-edi-srv-par.par_name = 'send-mail-profile'
      EXCLUSIVE-LOCK NO-ERROR.
    IF NOT AVAILABLE b3-aa-edi-srv-par
    THEN DO:
      CREATE b3-aa-edi-srv-par.
      ASSIGN 
      b3-aa-edi-srv-par.service_code = 'EMAIL'
      b3-aa-edi-srv-par.par_name = 'smtpversion'
      .
    END.
    ASSIGN 
      b3-aa-edi-srv-par.par_value = b1-aa-edi-srv-par.par_value.
      .
      
    /* is nu overgezet; oude parameter weggooien */  
    DELETE b1-aa-edi-srv-par.  
    
  END.


  iDone = iDone + 1.

  RUN DisplayProgress (cProgram, cAction, cTable, iTotal, iDone).


RUN DisplayProgress (cProgram, cAction, cTable, iTotal, iDone).
